<?php // @codingStandardsIgnoreLine
/**
 * User Registration Zapier Integration
 *
 * @package UserRegistrationZapier\admin
 * @version 1.0.0
 * @since   1.0.0
 */
class UR_Zapier_Frontend {

	/**
	 * Constructor.
	 */
	public function __construct() {
		add_action( 'user_registration_after_register_user_action', array( $this, 'ur_zapier_after_register_user_action' ), 10, 3 );
		add_action( 'user_registration_after_save_profile_validation', array( $this, 'ur_zapier_after_save_profile_validation' ), 10, 2 );
		add_action( 'user_registration_check_token_complete', array( $this, 'ur_zapier_after_email_confirmation' ), 10, 2 );
		add_action( 'woocommerce_checkout_update_user_meta', array( $this, 'ur_zapier_checkout_process' ), 10, 2 );
	}

	/**
	 * Sync to Zapier After Registeration.
	 *
	 * @param array $valid_form_data form data.
	 * @param int   $form_id form id.
	 * @param int   $user_id user id.
	 */
	public function ur_zapier_after_register_user_action( $valid_form_data, $form_id, $user_id ) {

		if ( $user_id < 1 ) {
			return;
		}

		$login_option     = ur_get_single_post_meta( $form_id, 'user_registration_form_setting_login_options', get_option( 'user_registration_general_setting_login_options', 'default' ) );
		$is_need_approval = ur_get_single_post_meta( $form_id, 'user_registration_zapier_need_user_approval', false );

		if ( $is_need_approval && ( 'email_confirmation' === $login_option || 'admin_approval' === $login_option ) ) {
			return;
		}

		$is_enable_zapier = ur_get_single_post_meta( $form_id, 'user_registration_enable_zapier', false );

		if ( $is_enable_zapier ) {
			ur_zapier_trigger_data( $valid_form_data, $form_id, $user_id );
		}
	}


	/**
	 * Sync Mailchimp after user update profile.
	 *
	 * @param int   $user_id Userid.
	 * @param array $profile Form Data.
	 */
	public function ur_zapier_after_save_profile_validation( $user_id, $profile ) {

		$form_id = get_user_meta( $user_id, 'ur_form_id', true );

		$is_enable_zapier          = ur_get_single_post_meta( $form_id, 'user_registration_enable_zapier', false );
		$trigger_on_update_enabled = ur_get_single_post_meta( $form_id, 'user_registration_zapier_trigger_on_profile_update', false );

		if ( $is_enable_zapier && $trigger_on_update_enabled ) {

			$valid_form_data = array();
			$single_field    = array();

			// Handle if edit profile saving as ajax form submission.
			if ( 'yes' === get_option( 'user_registration_ajax_form_submission_on_edit_profile', 'no' ) ) {
				$form_data = isset( $_POST['form_data'] ) ? json_decode( stripslashes( $_POST['form_data'] ) ) : array();

				foreach ( $form_data as $data ) {
					$single_field[ $data->field_name ] = isset( $data->value ) ? $data->value : '';
				}
			} else {
				$single_field = $_POST;
			}

			foreach ( $single_field as $post_key => $post_data ) {

				$pos = strpos( $post_key, 'user_registration_' );

				if ( false !== $pos ) {
					$new_string = substr_replace( $post_key, '', $pos, strlen( 'user_registration_' ) );

					if ( ! empty( $new_string ) ) {
						$tmp_array       = ur_get_valid_form_data_format( $new_string, $post_key, $profile, $post_data );
						$valid_form_data = array_merge( $valid_form_data, $tmp_array );
					}
				}
			}
			if ( count( $valid_form_data ) < 1 ) {
				return;
			}
			ur_zapier_trigger_data( $valid_form_data, $form_id, $user_id );
		}
	}

	/**
	 * Trigger hook After Email Confirmation
	 *
	 * @param int   $user_id User ID.
	 * @param mixed $user_reg_successful Email confitmation Status.
	 */
	public function ur_zapier_after_email_confirmation( $user_id, $user_reg_successful ) {

		$form_id          = ur_get_form_id_by_userid( $user_id );
		$is_need_approval = ur_get_single_post_meta( $form_id, 'user_registration_zapier_need_user_approval', false );
		$is_enable_zapier = ur_get_single_post_meta( $form_id, 'user_registration_enable_zapier', false );

		if ( $is_enable_zapier && $is_need_approval && $user_reg_successful ) {
			ur_zapier_trigger_after_approval( $user_id, $form_id );
		}
	}

	/**
	 * Trigger Hook on Woocommerce Checkout.
	 *
	 * @param int   $customer_id User ID.
	 * @param array $data Form Data.
	 */
	public function ur_zapier_checkout_process( $customer_id, $data ) {
		$checkout = WC()->checkout();

		if ( ! $checkout->is_registration_required() && empty( $_POST['createaccount'] ) ) {
			return;
		}

		$form_id       = get_option( 'user_registration_woocommerce_settings_form', 0 );
		$checkout_sync = get_option( 'user_registration_woocommrece_settings_sync_checkout', 'no' );

		$trigger_on_checkout = ur_get_single_post_meta( $form_id, 'user_registration_zapier_trigger_on_checkout', false );
		$is_enable_zapier    = ur_get_single_post_meta( $form_id, 'user_registration_enable_zapier', false );

		if ( 0 < $form_id && 'yes' === $checkout_sync && $is_enable_zapier && $trigger_on_checkout ) {

			$profile         = user_registration_form_data( $customer_id, $form_id );
			$valid_form_data = array();

			foreach ( $_POST as $post_key => $post_data ) {
				if ( 'billing_email' === $post_key ) {
					$post_key = 'user_registration_user_email';
				} elseif ( 'billing_first_name' === $post_key || 'billing_last_name' === $post_key ) {
					$post_key = 'billing_first_name' === $post_key ? 'user_registration_first_name' : 'user_registration_last_name';
				}

				$pos = strpos( $post_key, 'user_registration_' );

				if ( false !== $pos && isset( $profile[ $post_key ]['field_key'] ) ) {
					$new_string = substr_replace( $post_key, '', $pos, strlen( 'user_registration_' ) );

					if ( ! empty( $new_string ) ) {

						$tmp_array       = ur_get_valid_form_data_format( $new_string, $post_key, $profile, $post_data );
						$valid_form_data = array_merge( $valid_form_data, $tmp_array );
					}
				}
			}
			if ( count( $valid_form_data ) < 1 ) {
				return;
			}
			ur_zapier_trigger_data( $valid_form_data, $form_id, $customer_id );
		}
	}
}

return new UR_Zapier_Frontend();
