<?php
/**
 * User_Registration_Zapier setup
 *
 * @package User_Registration_Zapier
 * @since  1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


if ( ! class_exists( 'User_Registration_Zapier' ) ) :

	/**
	 * Main User_Registration_Zapier Class
	 *
	 * @class User_Registration_Zapier
	 */
	final class User_Registration_Zapier {


		/**
		 * Instance of this class.
		 *
		 * @var object
		 */
		protected static $_instance = null;

		/**
		 * Plugin Version
		 *
		 * @var string
		 */
		const VERSION = UR_ZAPIER_VERSION;

		/**
		 * Admin class instance
		 *
		 * @var \URS_Admin
		 * @since 1.0.0
		 */
		public $admin = null;

		/**
		 * Frontend class instance
		 *
		 * @var \URS_Frontend
		 * @since 1.0.0
		 */
		public $frontend = null;

		/**
		 * Return an instance of this class
		 *
		 * @return object A single instance of this class.
		 */
		public static function get_instance() {
			// If the single instance hasn't been set, set it now.
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * Constructor
		 *
		 * @since 1.0.0
		 */
		private function __construct() {
			// Checks if user registration plugin is installed.
			if ( defined( 'UR_VERSION' ) && version_compare( UR_VERSION, '1.9.0', '>=' ) ) {

				$this->includes();
				add_action( 'user_registration_init', array( $this, 'plugin_updater' ) );
				add_filter( 'plugin_action_links_' . plugin_basename( UR_ZAPIER_PLUGIN_FILE ), array( $this, 'plugin_action_links' ) );
				// rewrite rules.
				add_action( 'init', array( $this, 'rewrite_rules' ), 22 );

			} else {
				add_action( 'admin_notices', array( $this, 'user_registation_missing_notice' ) );
			}
		}

		/**
		 * Plugin Updater.
		 */
		public function plugin_updater() {
			if ( function_exists( 'ur_addon_updater' ) ) {
				ur_addon_updater( UR_ZAPIER_PLUGIN_FILE, 83024, self::VERSION );
			}
		}

		/**
		 * Includes.
		 */
		private function includes() {

			// Class admin.
			include_once dirname( __FILE__ ) . '/functions-zapier-handler.php';
			include_once dirname( __FILE__ ) . '/class-user-registration-zapier-admin.php';
			$this->admin = new UR_Zapier_Admin();
			// require file.
			include_once dirname( __FILE__ ) . '/class-user-registration-zapier-frontend.php';
		}

		/**
		 * Check if is admin or not and load the correct class
		 *
		 * @return bool
		 * @since 1.0.0
		 */
		public function is_admin() {
			$check_ajax    = defined( 'DOING_AJAX' ) && DOING_AJAX;
			$check_context = isset( $_REQUEST['context'] ) && 'frontend' == $_REQUEST['context'];

			return is_admin() && ! ( $check_ajax && $check_context );
		}

		/**
		 * User Registration fallback notice.
		 */
		public function user_registation_missing_notice() {
			/* translators: %s: user-registration plugin link */
			echo '<div class="error notice is-dismissible"><p>' . sprintf( esc_html__( 'User Registration Zapier requires %1$s version 1.9.0 or greater to work!', 'user-registration-zapier' ), '<a href="https://wpeverest.com/wordpress-plugins/user-registration/" target="_blank">' . esc_html__( 'User Registration', 'user-registration-zapier' ) . '</a>' ) . '</p></div>';     }

		/**
		 * Display action links in the Plugins list table.
		 *
		 * @param array $actions Add plugin action link.
		 *
		 * @return array
		 */
		public function plugin_action_links( $actions ) {
			$new_actions = array(
				'settings' => '<a href="' . admin_url( 'admin.php?page=user-registration-settings&tab=user-registration-zapier' ) . '" title="' . esc_attr( __( 'View User Registration Zapier Settings', 'user-registration-zapier' ) ) . '">' . __( 'Settings', 'user-registration-zapier' ) . '</a>',
			);

			return array_merge( $new_actions, $actions );
		}

		/**
		 * Rewrite rules
		 *
		 * @access public
		 * @since 1.0.0
		 */
		public function rewrite_rules() {
			$do_flush = get_option( 'ur-zapier-flush-rewrite-rules', 1 );

			if ( $do_flush ) {
				// change option.
				update_option( 'ur-zapier-flush-rewrite-rules', 0 );
				// the flush rewrite rules.
				flush_rewrite_rules();
			}
		}

		/**
		 * Get the plugin url.
		 *
		 * @return string
		 */
		public function plugin_url() {
			return untrailingslashit( plugins_url( '/', __FILE__ ) );
		}
	}
endif;

/**
 * Main instance of User_Registration_Zapier.
 *
 * @since  1.0.0
 * @return User_Registration_Zapier
 */
function UR_ZAPIER() {
	return User_Registration_Zapier::get_instance();
}
