<?php
/**
 * UserRegistrationZapier Hander Functions.
 *
 * General core functions available on both the front-end and admin.
 *
 * @package UserRegistrationZapier
 *
 * @version 1.0.0
 */

defined( 'ABSPATH' ) || exit;

/**
 * Trigger data to zapier via webhook.
 *
 * @param array $valid_form_data Form Data.
 * @param int   $form_id Form ID.
 * @param int   $user_id User ID.
 */
function ur_zapier_trigger_data( $valid_form_data, $form_id, $user_id ) {
	$labels   = array();
	$hook_url = ur_get_single_post_meta( $form_id, 'user_registration_zapier_webhook_url', false );

	$post_content_array = ( $form_id ) ? UR()->form->get_form( $form_id, array( 'content_only' => true ) ) : array();

	$fields_to_exclude = apply_filters(
		'user_registration_zapier_exclude_fields',
		array(
			'user_pass',
			'user_confirm_password',
			'user_confirm_email',
			'profile_picture',
		)
	);

	foreach ( $post_content_array as $post_content_row ) {
		foreach ( $post_content_row as $post_content_grid ) {

			foreach ( $post_content_grid as $field ) {
				$field_key = isset( $field->field_key ) ? ( $field->field_key ) : '';
				if ( in_array( $field_key, array( 'file', 'html', 'section_title' ), true ) ) {
					continue;
				}
				$field_name = isset( $field->general_setting->field_name ) ? $field->general_setting->field_name : '';
				if ( in_array( $field_name, $fields_to_exclude, true ) ) {
					continue;
				}
				$field_label = isset( $field->general_setting->label ) ? $field->general_setting->label : '';
				if ( array_key_exists( $field_label, $labels ) ) {
					$field_label = $field_label . ' (' . $field_name . ')';
				}

				if ( isset( $valid_form_data[ $field_name ] ) ) {
					if ( is_array( $valid_form_data[ $field_name ]->value ) ) {
						$valid_form_data[ $field_name ]->value = implode( ',', $valid_form_data[ $field_name ]->value );
					}
					if ( ( 'country' === $field_key || 'billing_country' === $field_key || 'shipping_country' === $field_key ) && '' !== $valid_form_data[ $field_name ]->value ) {
						$country_class                         = ur_load_form_field_class( $field_key );
						$countries                             = $country_class::get_instance()->get_country();
						$valid_form_data[ $field_name ]->value = isset( $countries[ $valid_form_data[ $field_name ]->value ] ) ? $countries[ $valid_form_data[ $field_name ]->value ] : $valid_form_data[ $field_name ]->value;
					}

					$labels[ $field_label ] = $valid_form_data[ $field_name ]->value;
				}
			}
		}
	}
	$headers  = array( 'Accept: application/json', 'Content-Type: application/json' );
	$args     = array(
		'method'  => 'POST',
		'body'    => json_encode( $labels ), // phpcs:ignore WordPress.WP.AlternativeFunctions.json_encode_json_encode
		'headers' => $headers,
	);
	
	$url = $hook_url;    
$content = json_encode($labels);

$curl = curl_init($url);
curl_setopt($curl, CURLOPT_HEADER, false);
curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
curl_setopt($curl, CURLOPT_HTTPHEADER,
        array("Content-type: application/json"));
curl_setopt($curl, CURLOPT_POST, true);
curl_setopt($curl, CURLOPT_POSTFIELDS, $content);

$json_response = curl_exec($curl);

$status = curl_getinfo($curl, CURLINFO_HTTP_CODE);

//if ( $status != 201 ) {
//    die("Error: call to URL $url failed with status $status, response $json_response, curl_error " . curl_error($curl) . ", curl_errno " . //curl_errno($curl));
//}


curl_close($curl);

$response = json_decode($json_response, true);
	
	
	
	
	
	
	//$response = wp_remote_post( $hook_url, $args['Name']);
	if ( is_wp_error( $response ) ) {
		ur_get_logger()->error( print_r( $response, true ) );
	}
}

/**
 * Trigger after email-confirmation and admin approval.
 *
 * @param int $user_id User Id.
 * @param int $form_id Form Id.
 */
function ur_zapier_trigger_after_approval( $user_id, $form_id ) {
	$user_data = get_user_meta( $user_id );
	$profile   = user_registration_form_data( $user_id, $form_id );
	$user      = get_user_by( 'id', $user_id );

	$user_data['user_registration_first_name'] = isset( $user_data['first_name'] ) ? $user_data['first_name'] : array();
	$user_data['user_registration_last_name']  = isset( $user_data['last_name'] ) ? $user_data['last_name'] : array();
	$user_data['user_registration_user_login'] = isset( $user->user_login ) ? array( $user->user_login ) : array();
	$user_data['user_registration_user_email'] = isset( $user->user_email ) ? array( $user->user_email ) : array();

	$valid_form_data = array();

	foreach ( $user_data as $post_key => $post_data ) {
		$pos_billing = strpos( $post_key, 'billing_' );
		if ( false !== $pos_billing ) {
			$post_key = 'user_registration_' . $post_key;
		}
		$pos_shipping = strpos( $post_key, 'shipping_' );
		if ( false !== $pos_shipping ) {
			$post_key = 'user_registration_' . $post_key;
		}
		$pos = strpos( $post_key, 'user_registration_' );

		if ( false !== $pos ) {
			$new_string = substr_replace( $post_key, '', $pos, strlen( 'user_registration_' ) );

			if ( ! empty( $new_string ) && 'geolocation' !== $new_string ) {
				$tmp_array       = ur_get_valid_form_data_format( $new_string, $post_key, $profile, $post_data[0] );
				$valid_form_data = array_merge( $valid_form_data, $tmp_array );
			}
		}
	}
	ur_zapier_trigger_data( $valid_form_data, $form_id, $user_id );
}
